@@ -3,15 +3,25 @@
 #ifndef _GVM_H
 #define _GVM_H
 
+#if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
+#define GNUC_UNUSED __attribute__((__unused__))
+#else
+#define GNUC_UNUSED
+#endif
+
 /* structure to represent the configuration of the volume manager */
 struct gvm_configuration {
 	GConfClient *client;
 	
+	char *filemanager;
+	
 	gboolean automount_drives;
 	gboolean automount_media;
 	gboolean autobrowse;
 	gboolean autorun;
 	char *autorun_path;
+	gboolean autoopen;
+	char *autoopen_path;
 	
 	gboolean autoburn;
 	char *autoburn_audio_cd_command;
@@ -35,6 +45,9 @@ struct gvm_configuration {
 	gboolean autoprinter;
 	char *autoprinter_command;
 	
+	gboolean autowebcam;
+	char *autowebcam_command;
+
 	gboolean autoscanner;
 	char *autoscanner_command;
 	
